#!/usr/bin/env python
# coding: utf-8

import subprocess
import sys

TRADUCTIONS = {
    u'tracte': u'pull',
    u"pulse": u"push",
    u"forme": u"clone",
    u"bine": u"merge",
    u"fonde": u"rebase",
    u"pare": u"diff",
    u"signe": u"log",
    u"state": u"status",
    u"comitant": u"commit"
}


def traduit_commande(commande):
    if commande in TRADUCTIONS.keys():
        return TRADUCTIONS[commande]
    else:
        return commande


def remplace_commande_principale(commande):
    commande[0] = 'git'
    return commande


def traduit_ligne_commande(ligne_commande):
    return [traduit_commande(arg) for arg in ligne_commande]


def main():
    ligne_commande = remplace_commande_principale(sys.argv)
    command_line_list = traduit_ligne_commande(ligne_commande)
    subprocess.call(command_line_list)


if __name__ == '__main__':  # pragma: no cover
    main()



# coding: utf-8

from setuptools import setup, find_packages

long_description = """
Con is a French wrapper around the git toolbox

## Examples

* ``git push`` → ``con pulse``
* ``git pull`` → ``con tracte``
* ``git merge`` → ``con bine``
"""

setup(
    name='con_trefacon',
    version="0.0.1",
    license='3-clause BSD',
    description='Con, comme git, mais en français',
    long_description=long_description,
    long_description_content_type='text/markdown',
    author="Bastien Gallay",
    author_email="bastien@gallay.org",
    url='http://github.com/elbabass/con',
    py_modules=['con'],
    entry_points={'console_scripts': ['con=con:main']},
    packages=find_packages(exclude=("tests",)),
    classifiers=[
        'Environment :: Console',
        'License :: OSI Approved :: BSD License',
        'Operating System :: Unix',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
        'Topic :: Software Development :: Build Tools',
    ]
)
